# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2
from injective.exchange.v1beta1 import tx_pb2 as injective_dot_exchange_dot_v1beta1_dot_tx__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/exchange/v1beta1/genesis.proto',
  package='injective.exchange.v1beta1',
  syntax='proto3',
  serialized_options=b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(injective/exchange/v1beta1/genesis.proto\x12\x1ainjective.exchange.v1beta1\x1a)injective/exchange/v1beta1/exchange.proto\x1a#injective/exchange/v1beta1/tx.proto\x1a\x14gogoproto/gogo.proto\"\xd9\x12\n\x0cGenesisState\x12\x38\n\x06params\x18\x01 \x01(\x0b\x32\".injective.exchange.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12<\n\x0cspot_markets\x18\x02 \x03(\x0b\x32&.injective.exchange.v1beta1.SpotMarket\x12H\n\x12\x64\x65rivative_markets\x18\x03 \x03(\x0b\x32,.injective.exchange.v1beta1.DerivativeMarket\x12G\n\x0espot_orderbook\x18\x04 \x03(\x0b\x32).injective.exchange.v1beta1.SpotOrderBookB\x04\xc8\xde\x1f\x00\x12S\n\x14\x64\x65rivative_orderbook\x18\x05 \x03(\x0b\x32/.injective.exchange.v1beta1.DerivativeOrderBookB\x04\xc8\xde\x1f\x00\x12;\n\x08\x62\x61lances\x18\x06 \x03(\x0b\x32#.injective.exchange.v1beta1.BalanceB\x04\xc8\xde\x1f\x00\x12G\n\tpositions\x18\x07 \x03(\x0b\x32..injective.exchange.v1beta1.DerivativePositionB\x04\xc8\xde\x1f\x00\x12R\n\x17subaccount_trade_nonces\x18\x08 \x03(\x0b\x32+.injective.exchange.v1beta1.SubaccountNonceB\x04\xc8\xde\x1f\x00\x12h\n expiry_futures_market_info_state\x18\t \x03(\x0b\x32\x38.injective.exchange.v1beta1.ExpiryFuturesMarketInfoStateB\x04\xc8\xde\x1f\x00\x12T\n\x15perpetual_market_info\x18\n \x03(\x0b\x32/.injective.exchange.v1beta1.PerpetualMarketInfoB\x04\xc8\xde\x1f\x00\x12\x65\n\x1eperpetual_market_funding_state\x18\x0b \x03(\x0b\x32\x37.injective.exchange.v1beta1.PerpetualMarketFundingStateB\x04\xc8\xde\x1f\x00\x12p\n&derivative_market_settlement_scheduled\x18\x0c \x03(\x0b\x32:.injective.exchange.v1beta1.DerivativeMarketSettlementInfoB\x04\xc8\xde\x1f\x00\x12 \n\x18is_spot_exchange_enabled\x18\r \x01(\x08\x12\'\n\x1fis_derivatives_exchange_enabled\x18\x0e \x01(\x08\x12[\n\x1ctrading_reward_campaign_info\x18\x0f \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfo\x12]\n%trading_reward_pool_campaign_schedule\x18\x10 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\x12n\n&trading_reward_campaign_account_points\x18\x11 \x03(\x0b\x32>.injective.exchange.v1beta1.TradingRewardCampaignAccountPoints\x12N\n\x15\x66\x65\x65_discount_schedule\x18\x12 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountSchedule\x12\\\n\x1d\x66\x65\x65_discount_account_tier_ttl\x18\x13 \x03(\x0b\x32\x35.injective.exchange.v1beta1.FeeDiscountAccountTierTTL\x12h\n#fee_discount_bucket_volume_accounts\x18\x14 \x03(\x0b\x32;.injective.exchange.v1beta1.FeeDiscountBucketVolumeAccounts\x12#\n\x1bis_first_fee_cycle_finished\x18\x15 \x01(\x08\x12\x65\n-pending_trading_reward_pool_campaign_schedule\x18\x16 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\x12}\n.pending_trading_reward_campaign_account_points\x18\x17 \x03(\x0b\x32\x45.injective.exchange.v1beta1.TradingRewardCampaignAccountPendingPoints\x12!\n\x19rewards_opt_out_addresses\x18\x18 \x03(\t\x12J\n\x18historical_trade_records\x18\x19 \x03(\x0b\x32(.injective.exchange.v1beta1.TradeRecords\x12O\n\x16\x62inary_options_markets\x18\x1a \x03(\x0b\x32/.injective.exchange.v1beta1.BinaryOptionsMarket\x12:\n2binary_options_market_ids_scheduled_for_settlement\x18\x1b \x03(\t\x12\x30\n(spot_market_ids_scheduled_to_force_close\x18\x1c \x03(\t\x12G\n\x0e\x64\x65nom_decimals\x18\x1d \x03(\x0b\x32).injective.exchange.v1beta1.DenomDecimalsB\x04\xc8\xde\x1f\x00\x12\x65\n!conditional_derivative_orderbooks\x18\x1e \x03(\x0b\x32:.injective.exchange.v1beta1.ConditionalDerivativeOrderBook\"n\n\x19\x46\x65\x65\x44iscountAccountTierTTL\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12@\n\x08tier_ttl\x18\x02 \x01(\x0b\x32..injective.exchange.v1beta1.FeeDiscountTierTTL\"\x84\x01\n\x1f\x46\x65\x65\x44iscountBucketVolumeAccounts\x12\x1e\n\x16\x62ucket_start_timestamp\x18\x01 \x01(\x03\x12\x41\n\x0e\x61\x63\x63ount_volume\x18\x02 \x03(\x0b\x32).injective.exchange.v1beta1.AccountVolume\"`\n\rAccountVolume\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12>\n\x06volume\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"u\n\"TradingRewardCampaignAccountPoints\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12>\n\x06points\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xa8\x01\n)TradingRewardCampaignAccountPendingPoints\x12#\n\x1breward_pool_start_timestamp\x18\x01 \x01(\x03\x12V\n\x0e\x61\x63\x63ount_points\x18\x02 \x03(\x0b\x32>.injective.exchange.v1beta1.TradingRewardCampaignAccountPoints\"{\n\rSpotOrderBook\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x11\n\tisBuySide\x18\x02 \x01(\x08\x12:\n\x06orders\x18\x03 \x03(\x0b\x32*.injective.exchange.v1beta1.SpotLimitOrder:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x87\x01\n\x13\x44\x65rivativeOrderBook\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x11\n\tisBuySide\x18\x02 \x01(\x08\x12@\n\x06orders\x18\x03 \x03(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrder:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xf3\x02\n\x1e\x43onditionalDerivativeOrderBook\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12J\n\x10limit_buy_orders\x18\x02 \x03(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrder\x12L\n\x11market_buy_orders\x18\x03 \x03(\x0b\x32\x31.injective.exchange.v1beta1.DerivativeMarketOrder\x12K\n\x11limit_sell_orders\x18\x04 \x03(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrder\x12M\n\x12market_sell_orders\x18\x05 \x03(\x0b\x32\x31.injective.exchange.v1beta1.DerivativeMarketOrder:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"p\n\x07\x42\x61lance\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x35\n\x08\x64\x65posits\x18\x03 \x01(\x0b\x32#.injective.exchange.v1beta1.Deposit:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x80\x01\n\x12\x44\x65rivativePosition\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x36\n\x08position\x18\x03 \x01(\x0b\x32$.injective.exchange.v1beta1.Position:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x8a\x01\n\x0fSubaccountNonce\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12V\n\x16subaccount_trade_nonce\x18\x02 \x01(\x0b\x32\x30.injective.exchange.v1beta1.SubaccountTradeNonceB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"{\n\x1c\x45xpiryFuturesMarketInfoState\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12H\n\x0bmarket_info\x18\x02 \x01(\x0b\x32\x33.injective.exchange.v1beta1.ExpiryFuturesMarketInfo\"u\n\x1bPerpetualMarketFundingState\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x43\n\x07\x66unding\x18\x02 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFundingBPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3'
  ,
  dependencies=[injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.DESCRIPTOR,injective_dot_exchange_dot_v1beta1_dot_tx__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_GENESISSTATE = _descriptor.Descriptor(
  name='GenesisState',
  full_name='injective.exchange.v1beta1.GenesisState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.exchange.v1beta1.GenesisState.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_markets', full_name='injective.exchange.v1beta1.GenesisState.spot_markets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_markets', full_name='injective.exchange.v1beta1.GenesisState.derivative_markets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_orderbook', full_name='injective.exchange.v1beta1.GenesisState.spot_orderbook', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_orderbook', full_name='injective.exchange.v1beta1.GenesisState.derivative_orderbook', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balances', full_name='injective.exchange.v1beta1.GenesisState.balances', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positions', full_name='injective.exchange.v1beta1.GenesisState.positions', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_trade_nonces', full_name='injective.exchange.v1beta1.GenesisState.subaccount_trade_nonces', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry_futures_market_info_state', full_name='injective.exchange.v1beta1.GenesisState.expiry_futures_market_info_state', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perpetual_market_info', full_name='injective.exchange.v1beta1.GenesisState.perpetual_market_info', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perpetual_market_funding_state', full_name='injective.exchange.v1beta1.GenesisState.perpetual_market_funding_state', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_market_settlement_scheduled', full_name='injective.exchange.v1beta1.GenesisState.derivative_market_settlement_scheduled', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_spot_exchange_enabled', full_name='injective.exchange.v1beta1.GenesisState.is_spot_exchange_enabled', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_derivatives_exchange_enabled', full_name='injective.exchange.v1beta1.GenesisState.is_derivatives_exchange_enabled', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trading_reward_campaign_info', full_name='injective.exchange.v1beta1.GenesisState.trading_reward_campaign_info', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trading_reward_pool_campaign_schedule', full_name='injective.exchange.v1beta1.GenesisState.trading_reward_pool_campaign_schedule', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trading_reward_campaign_account_points', full_name='injective.exchange.v1beta1.GenesisState.trading_reward_campaign_account_points', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_discount_schedule', full_name='injective.exchange.v1beta1.GenesisState.fee_discount_schedule', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_discount_account_tier_ttl', full_name='injective.exchange.v1beta1.GenesisState.fee_discount_account_tier_ttl', index=18,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_discount_bucket_volume_accounts', full_name='injective.exchange.v1beta1.GenesisState.fee_discount_bucket_volume_accounts', index=19,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_first_fee_cycle_finished', full_name='injective.exchange.v1beta1.GenesisState.is_first_fee_cycle_finished', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_trading_reward_pool_campaign_schedule', full_name='injective.exchange.v1beta1.GenesisState.pending_trading_reward_pool_campaign_schedule', index=21,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_trading_reward_campaign_account_points', full_name='injective.exchange.v1beta1.GenesisState.pending_trading_reward_campaign_account_points', index=22,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewards_opt_out_addresses', full_name='injective.exchange.v1beta1.GenesisState.rewards_opt_out_addresses', index=23,
      number=24, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='historical_trade_records', full_name='injective.exchange.v1beta1.GenesisState.historical_trade_records', index=24,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_options_markets', full_name='injective.exchange.v1beta1.GenesisState.binary_options_markets', index=25,
      number=26, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_options_market_ids_scheduled_for_settlement', full_name='injective.exchange.v1beta1.GenesisState.binary_options_market_ids_scheduled_for_settlement', index=26,
      number=27, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_market_ids_scheduled_to_force_close', full_name='injective.exchange.v1beta1.GenesisState.spot_market_ids_scheduled_to_force_close', index=27,
      number=28, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom_decimals', full_name='injective.exchange.v1beta1.GenesisState.denom_decimals', index=28,
      number=29, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditional_derivative_orderbooks', full_name='injective.exchange.v1beta1.GenesisState.conditional_derivative_orderbooks', index=29,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=2568,
)


_FEEDISCOUNTACCOUNTTIERTTL = _descriptor.Descriptor(
  name='FeeDiscountAccountTierTTL',
  full_name='injective.exchange.v1beta1.FeeDiscountAccountTierTTL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='injective.exchange.v1beta1.FeeDiscountAccountTierTTL.account', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tier_ttl', full_name='injective.exchange.v1beta1.FeeDiscountAccountTierTTL.tier_ttl', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2570,
  serialized_end=2680,
)


_FEEDISCOUNTBUCKETVOLUMEACCOUNTS = _descriptor.Descriptor(
  name='FeeDiscountBucketVolumeAccounts',
  full_name='injective.exchange.v1beta1.FeeDiscountBucketVolumeAccounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket_start_timestamp', full_name='injective.exchange.v1beta1.FeeDiscountBucketVolumeAccounts.bucket_start_timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_volume', full_name='injective.exchange.v1beta1.FeeDiscountBucketVolumeAccounts.account_volume', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2683,
  serialized_end=2815,
)


_ACCOUNTVOLUME = _descriptor.Descriptor(
  name='AccountVolume',
  full_name='injective.exchange.v1beta1.AccountVolume',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='injective.exchange.v1beta1.AccountVolume.account', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='injective.exchange.v1beta1.AccountVolume.volume', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2817,
  serialized_end=2913,
)


_TRADINGREWARDCAMPAIGNACCOUNTPOINTS = _descriptor.Descriptor(
  name='TradingRewardCampaignAccountPoints',
  full_name='injective.exchange.v1beta1.TradingRewardCampaignAccountPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='injective.exchange.v1beta1.TradingRewardCampaignAccountPoints.account', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points', full_name='injective.exchange.v1beta1.TradingRewardCampaignAccountPoints.points', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2915,
  serialized_end=3032,
)


_TRADINGREWARDCAMPAIGNACCOUNTPENDINGPOINTS = _descriptor.Descriptor(
  name='TradingRewardCampaignAccountPendingPoints',
  full_name='injective.exchange.v1beta1.TradingRewardCampaignAccountPendingPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reward_pool_start_timestamp', full_name='injective.exchange.v1beta1.TradingRewardCampaignAccountPendingPoints.reward_pool_start_timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_points', full_name='injective.exchange.v1beta1.TradingRewardCampaignAccountPendingPoints.account_points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3035,
  serialized_end=3203,
)


_SPOTORDERBOOK = _descriptor.Descriptor(
  name='SpotOrderBook',
  full_name='injective.exchange.v1beta1.SpotOrderBook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.SpotOrderBook.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isBuySide', full_name='injective.exchange.v1beta1.SpotOrderBook.isBuySide', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective.exchange.v1beta1.SpotOrderBook.orders', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3205,
  serialized_end=3328,
)


_DERIVATIVEORDERBOOK = _descriptor.Descriptor(
  name='DerivativeOrderBook',
  full_name='injective.exchange.v1beta1.DerivativeOrderBook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.DerivativeOrderBook.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isBuySide', full_name='injective.exchange.v1beta1.DerivativeOrderBook.isBuySide', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective.exchange.v1beta1.DerivativeOrderBook.orders', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3331,
  serialized_end=3466,
)


_CONDITIONALDERIVATIVEORDERBOOK = _descriptor.Descriptor(
  name='ConditionalDerivativeOrderBook',
  full_name='injective.exchange.v1beta1.ConditionalDerivativeOrderBook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.ConditionalDerivativeOrderBook.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_buy_orders', full_name='injective.exchange.v1beta1.ConditionalDerivativeOrderBook.limit_buy_orders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_buy_orders', full_name='injective.exchange.v1beta1.ConditionalDerivativeOrderBook.market_buy_orders', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_sell_orders', full_name='injective.exchange.v1beta1.ConditionalDerivativeOrderBook.limit_sell_orders', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_sell_orders', full_name='injective.exchange.v1beta1.ConditionalDerivativeOrderBook.market_sell_orders', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3469,
  serialized_end=3840,
)


_BALANCE = _descriptor.Descriptor(
  name='Balance',
  full_name='injective.exchange.v1beta1.Balance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.Balance.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective.exchange.v1beta1.Balance.denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposits', full_name='injective.exchange.v1beta1.Balance.deposits', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3842,
  serialized_end=3954,
)


_DERIVATIVEPOSITION = _descriptor.Descriptor(
  name='DerivativePosition',
  full_name='injective.exchange.v1beta1.DerivativePosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.DerivativePosition.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.DerivativePosition.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='injective.exchange.v1beta1.DerivativePosition.position', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3957,
  serialized_end=4085,
)


_SUBACCOUNTNONCE = _descriptor.Descriptor(
  name='SubaccountNonce',
  full_name='injective.exchange.v1beta1.SubaccountNonce',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.SubaccountNonce.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_trade_nonce', full_name='injective.exchange.v1beta1.SubaccountNonce.subaccount_trade_nonce', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4088,
  serialized_end=4226,
)


_EXPIRYFUTURESMARKETINFOSTATE = _descriptor.Descriptor(
  name='ExpiryFuturesMarketInfoState',
  full_name='injective.exchange.v1beta1.ExpiryFuturesMarketInfoState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketInfoState.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_info', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketInfoState.market_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4228,
  serialized_end=4351,
)


_PERPETUALMARKETFUNDINGSTATE = _descriptor.Descriptor(
  name='PerpetualMarketFundingState',
  full_name='injective.exchange.v1beta1.PerpetualMarketFundingState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.PerpetualMarketFundingState.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding', full_name='injective.exchange.v1beta1.PerpetualMarketFundingState.funding', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4353,
  serialized_end=4470,
)

_GENESISSTATE.fields_by_name['params'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PARAMS
_GENESISSTATE.fields_by_name['spot_markets'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTMARKET
_GENESISSTATE.fields_by_name['derivative_markets'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEMARKET
_GENESISSTATE.fields_by_name['spot_orderbook'].message_type = _SPOTORDERBOOK
_GENESISSTATE.fields_by_name['derivative_orderbook'].message_type = _DERIVATIVEORDERBOOK
_GENESISSTATE.fields_by_name['balances'].message_type = _BALANCE
_GENESISSTATE.fields_by_name['positions'].message_type = _DERIVATIVEPOSITION
_GENESISSTATE.fields_by_name['subaccount_trade_nonces'].message_type = _SUBACCOUNTNONCE
_GENESISSTATE.fields_by_name['expiry_futures_market_info_state'].message_type = _EXPIRYFUTURESMARKETINFOSTATE
_GENESISSTATE.fields_by_name['perpetual_market_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PERPETUALMARKETINFO
_GENESISSTATE.fields_by_name['perpetual_market_funding_state'].message_type = _PERPETUALMARKETFUNDINGSTATE
_GENESISSTATE.fields_by_name['derivative_market_settlement_scheduled'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEMARKETSETTLEMENTINFO
_GENESISSTATE.fields_by_name['trading_reward_campaign_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._TRADINGREWARDCAMPAIGNINFO
_GENESISSTATE.fields_by_name['trading_reward_pool_campaign_schedule'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._CAMPAIGNREWARDPOOL
_GENESISSTATE.fields_by_name['trading_reward_campaign_account_points'].message_type = _TRADINGREWARDCAMPAIGNACCOUNTPOINTS
_GENESISSTATE.fields_by_name['fee_discount_schedule'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._FEEDISCOUNTSCHEDULE
_GENESISSTATE.fields_by_name['fee_discount_account_tier_ttl'].message_type = _FEEDISCOUNTACCOUNTTIERTTL
_GENESISSTATE.fields_by_name['fee_discount_bucket_volume_accounts'].message_type = _FEEDISCOUNTBUCKETVOLUMEACCOUNTS
_GENESISSTATE.fields_by_name['pending_trading_reward_pool_campaign_schedule'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._CAMPAIGNREWARDPOOL
_GENESISSTATE.fields_by_name['pending_trading_reward_campaign_account_points'].message_type = _TRADINGREWARDCAMPAIGNACCOUNTPENDINGPOINTS
_GENESISSTATE.fields_by_name['historical_trade_records'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._TRADERECORDS
_GENESISSTATE.fields_by_name['binary_options_markets'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._BINARYOPTIONSMARKET
_GENESISSTATE.fields_by_name['denom_decimals'].message_type = injective_dot_exchange_dot_v1beta1_dot_tx__pb2._DENOMDECIMALS
_GENESISSTATE.fields_by_name['conditional_derivative_orderbooks'].message_type = _CONDITIONALDERIVATIVEORDERBOOK
_FEEDISCOUNTACCOUNTTIERTTL.fields_by_name['tier_ttl'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._FEEDISCOUNTTIERTTL
_FEEDISCOUNTBUCKETVOLUMEACCOUNTS.fields_by_name['account_volume'].message_type = _ACCOUNTVOLUME
_TRADINGREWARDCAMPAIGNACCOUNTPENDINGPOINTS.fields_by_name['account_points'].message_type = _TRADINGREWARDCAMPAIGNACCOUNTPOINTS
_SPOTORDERBOOK.fields_by_name['orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTLIMITORDER
_DERIVATIVEORDERBOOK.fields_by_name['orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVELIMITORDER
_CONDITIONALDERIVATIVEORDERBOOK.fields_by_name['limit_buy_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVELIMITORDER
_CONDITIONALDERIVATIVEORDERBOOK.fields_by_name['market_buy_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEMARKETORDER
_CONDITIONALDERIVATIVEORDERBOOK.fields_by_name['limit_sell_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVELIMITORDER
_CONDITIONALDERIVATIVEORDERBOOK.fields_by_name['market_sell_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEMARKETORDER
_BALANCE.fields_by_name['deposits'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DEPOSIT
_DERIVATIVEPOSITION.fields_by_name['position'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._POSITION
_SUBACCOUNTNONCE.fields_by_name['subaccount_trade_nonce'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SUBACCOUNTTRADENONCE
_EXPIRYFUTURESMARKETINFOSTATE.fields_by_name['market_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._EXPIRYFUTURESMARKETINFO
_PERPETUALMARKETFUNDINGSTATE.fields_by_name['funding'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PERPETUALMARKETFUNDING
DESCRIPTOR.message_types_by_name['GenesisState'] = _GENESISSTATE
DESCRIPTOR.message_types_by_name['FeeDiscountAccountTierTTL'] = _FEEDISCOUNTACCOUNTTIERTTL
DESCRIPTOR.message_types_by_name['FeeDiscountBucketVolumeAccounts'] = _FEEDISCOUNTBUCKETVOLUMEACCOUNTS
DESCRIPTOR.message_types_by_name['AccountVolume'] = _ACCOUNTVOLUME
DESCRIPTOR.message_types_by_name['TradingRewardCampaignAccountPoints'] = _TRADINGREWARDCAMPAIGNACCOUNTPOINTS
DESCRIPTOR.message_types_by_name['TradingRewardCampaignAccountPendingPoints'] = _TRADINGREWARDCAMPAIGNACCOUNTPENDINGPOINTS
DESCRIPTOR.message_types_by_name['SpotOrderBook'] = _SPOTORDERBOOK
DESCRIPTOR.message_types_by_name['DerivativeOrderBook'] = _DERIVATIVEORDERBOOK
DESCRIPTOR.message_types_by_name['ConditionalDerivativeOrderBook'] = _CONDITIONALDERIVATIVEORDERBOOK
DESCRIPTOR.message_types_by_name['Balance'] = _BALANCE
DESCRIPTOR.message_types_by_name['DerivativePosition'] = _DERIVATIVEPOSITION
DESCRIPTOR.message_types_by_name['SubaccountNonce'] = _SUBACCOUNTNONCE
DESCRIPTOR.message_types_by_name['ExpiryFuturesMarketInfoState'] = _EXPIRYFUTURESMARKETINFOSTATE
DESCRIPTOR.message_types_by_name['PerpetualMarketFundingState'] = _PERPETUALMARKETFUNDINGSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

FeeDiscountAccountTierTTL = _reflection.GeneratedProtocolMessageType('FeeDiscountAccountTierTTL', (_message.Message,), {
  'DESCRIPTOR' : _FEEDISCOUNTACCOUNTTIERTTL,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.FeeDiscountAccountTierTTL)
  })
_sym_db.RegisterMessage(FeeDiscountAccountTierTTL)

FeeDiscountBucketVolumeAccounts = _reflection.GeneratedProtocolMessageType('FeeDiscountBucketVolumeAccounts', (_message.Message,), {
  'DESCRIPTOR' : _FEEDISCOUNTBUCKETVOLUMEACCOUNTS,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.FeeDiscountBucketVolumeAccounts)
  })
_sym_db.RegisterMessage(FeeDiscountBucketVolumeAccounts)

AccountVolume = _reflection.GeneratedProtocolMessageType('AccountVolume', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTVOLUME,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.AccountVolume)
  })
_sym_db.RegisterMessage(AccountVolume)

TradingRewardCampaignAccountPoints = _reflection.GeneratedProtocolMessageType('TradingRewardCampaignAccountPoints', (_message.Message,), {
  'DESCRIPTOR' : _TRADINGREWARDCAMPAIGNACCOUNTPOINTS,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TradingRewardCampaignAccountPoints)
  })
_sym_db.RegisterMessage(TradingRewardCampaignAccountPoints)

TradingRewardCampaignAccountPendingPoints = _reflection.GeneratedProtocolMessageType('TradingRewardCampaignAccountPendingPoints', (_message.Message,), {
  'DESCRIPTOR' : _TRADINGREWARDCAMPAIGNACCOUNTPENDINGPOINTS,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TradingRewardCampaignAccountPendingPoints)
  })
_sym_db.RegisterMessage(TradingRewardCampaignAccountPendingPoints)

SpotOrderBook = _reflection.GeneratedProtocolMessageType('SpotOrderBook', (_message.Message,), {
  'DESCRIPTOR' : _SPOTORDERBOOK,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SpotOrderBook)
  })
_sym_db.RegisterMessage(SpotOrderBook)

DerivativeOrderBook = _reflection.GeneratedProtocolMessageType('DerivativeOrderBook', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEORDERBOOK,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DerivativeOrderBook)
  })
_sym_db.RegisterMessage(DerivativeOrderBook)

ConditionalDerivativeOrderBook = _reflection.GeneratedProtocolMessageType('ConditionalDerivativeOrderBook', (_message.Message,), {
  'DESCRIPTOR' : _CONDITIONALDERIVATIVEORDERBOOK,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.ConditionalDerivativeOrderBook)
  })
_sym_db.RegisterMessage(ConditionalDerivativeOrderBook)

Balance = _reflection.GeneratedProtocolMessageType('Balance', (_message.Message,), {
  'DESCRIPTOR' : _BALANCE,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.Balance)
  })
_sym_db.RegisterMessage(Balance)

DerivativePosition = _reflection.GeneratedProtocolMessageType('DerivativePosition', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEPOSITION,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DerivativePosition)
  })
_sym_db.RegisterMessage(DerivativePosition)

SubaccountNonce = _reflection.GeneratedProtocolMessageType('SubaccountNonce', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTNONCE,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SubaccountNonce)
  })
_sym_db.RegisterMessage(SubaccountNonce)

ExpiryFuturesMarketInfoState = _reflection.GeneratedProtocolMessageType('ExpiryFuturesMarketInfoState', (_message.Message,), {
  'DESCRIPTOR' : _EXPIRYFUTURESMARKETINFOSTATE,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.ExpiryFuturesMarketInfoState)
  })
_sym_db.RegisterMessage(ExpiryFuturesMarketInfoState)

PerpetualMarketFundingState = _reflection.GeneratedProtocolMessageType('PerpetualMarketFundingState', (_message.Message,), {
  'DESCRIPTOR' : _PERPETUALMARKETFUNDINGSTATE,
  '__module__' : 'injective.exchange.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.PerpetualMarketFundingState)
  })
_sym_db.RegisterMessage(PerpetualMarketFundingState)


DESCRIPTOR._options = None
_GENESISSTATE.fields_by_name['params']._options = None
_GENESISSTATE.fields_by_name['spot_orderbook']._options = None
_GENESISSTATE.fields_by_name['derivative_orderbook']._options = None
_GENESISSTATE.fields_by_name['balances']._options = None
_GENESISSTATE.fields_by_name['positions']._options = None
_GENESISSTATE.fields_by_name['subaccount_trade_nonces']._options = None
_GENESISSTATE.fields_by_name['expiry_futures_market_info_state']._options = None
_GENESISSTATE.fields_by_name['perpetual_market_info']._options = None
_GENESISSTATE.fields_by_name['perpetual_market_funding_state']._options = None
_GENESISSTATE.fields_by_name['derivative_market_settlement_scheduled']._options = None
_GENESISSTATE.fields_by_name['denom_decimals']._options = None
_ACCOUNTVOLUME.fields_by_name['volume']._options = None
_TRADINGREWARDCAMPAIGNACCOUNTPOINTS.fields_by_name['points']._options = None
_SPOTORDERBOOK._options = None
_DERIVATIVEORDERBOOK._options = None
_CONDITIONALDERIVATIVEORDERBOOK._options = None
_BALANCE._options = None
_DERIVATIVEPOSITION._options = None
_SUBACCOUNTNONCE.fields_by_name['subaccount_trade_nonce']._options = None
_SUBACCOUNTNONCE._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from injective.oracle.v1beta1 import tx_pb2 as injective_dot_oracle_dot_v1beta1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the oracle Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RelayProviderPrices = channel.unary_unary(
                '/injective.oracle.v1beta1.Msg/RelayProviderPrices',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayProviderPrices.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayProviderPricesResponse.FromString,
                )
        self.RelayPriceFeedPrice = channel.unary_unary(
                '/injective.oracle.v1beta1.Msg/RelayPriceFeedPrice',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayPriceFeedPrice.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayPriceFeedPriceResponse.FromString,
                )
        self.RelayBandRates = channel.unary_unary(
                '/injective.oracle.v1beta1.Msg/RelayBandRates',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayBandRates.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayBandRatesResponse.FromString,
                )
        self.RequestBandIBCRates = channel.unary_unary(
                '/injective.oracle.v1beta1.Msg/RequestBandIBCRates',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRequestBandIBCRates.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRequestBandIBCRatesResponse.FromString,
                )
        self.RelayCoinbaseMessages = channel.unary_unary(
                '/injective.oracle.v1beta1.Msg/RelayCoinbaseMessages',
                request_serializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayCoinbaseMessages.SerializeToString,
                response_deserializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayCoinbaseMessagesResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the oracle Msg service.
    """

    def RelayProviderPrices(self, request, context):
        """RelayProviderPrice defines a method for relaying a price for a provider-based oracle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RelayPriceFeedPrice(self, request, context):
        """RelayPriceFeedPrice defines a method for relaying a price for a price feeder-based oracle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RelayBandRates(self, request, context):
        """RelayBandRates defines a method for relaying rates from Band
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RequestBandIBCRates(self, request, context):
        """RequestBandIBCRates defines a method for fetching rates from Band ibc
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RelayCoinbaseMessages(self, request, context):
        """RelayCoinbaseMessages defines a method for relaying price messages from Coinbase API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RelayProviderPrices': grpc.unary_unary_rpc_method_handler(
                    servicer.RelayProviderPrices,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayProviderPrices.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayProviderPricesResponse.SerializeToString,
            ),
            'RelayPriceFeedPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.RelayPriceFeedPrice,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayPriceFeedPrice.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayPriceFeedPriceResponse.SerializeToString,
            ),
            'RelayBandRates': grpc.unary_unary_rpc_method_handler(
                    servicer.RelayBandRates,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayBandRates.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayBandRatesResponse.SerializeToString,
            ),
            'RequestBandIBCRates': grpc.unary_unary_rpc_method_handler(
                    servicer.RequestBandIBCRates,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRequestBandIBCRates.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRequestBandIBCRatesResponse.SerializeToString,
            ),
            'RelayCoinbaseMessages': grpc.unary_unary_rpc_method_handler(
                    servicer.RelayCoinbaseMessages,
                    request_deserializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayCoinbaseMessages.FromString,
                    response_serializer=injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayCoinbaseMessagesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.oracle.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the oracle Msg service.
    """

    @staticmethod
    def RelayProviderPrices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.oracle.v1beta1.Msg/RelayProviderPrices',
            injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayProviderPrices.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayProviderPricesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RelayPriceFeedPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.oracle.v1beta1.Msg/RelayPriceFeedPrice',
            injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayPriceFeedPrice.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayPriceFeedPriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RelayBandRates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.oracle.v1beta1.Msg/RelayBandRates',
            injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayBandRates.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayBandRatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RequestBandIBCRates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.oracle.v1beta1.Msg/RequestBandIBCRates',
            injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRequestBandIBCRates.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRequestBandIBCRatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RelayCoinbaseMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.oracle.v1beta1.Msg/RelayCoinbaseMessages',
            injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayCoinbaseMessages.SerializeToString,
            injective_dot_oracle_dot_v1beta1_dot_tx__pb2.MsgRelayCoinbaseMessagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from cosmos.authz.v1beta1 import tx_pb2 as cosmos_dot_authz_dot_v1beta1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the authz Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Grant = channel.unary_unary(
                '/cosmos.authz.v1beta1.Msg/Grant',
                request_serializer=cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgGrant.SerializeToString,
                response_deserializer=cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgGrantResponse.FromString,
                )
        self.Exec = channel.unary_unary(
                '/cosmos.authz.v1beta1.Msg/Exec',
                request_serializer=cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgExec.SerializeToString,
                response_deserializer=cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgExecResponse.FromString,
                )
        self.Revoke = channel.unary_unary(
                '/cosmos.authz.v1beta1.Msg/Revoke',
                request_serializer=cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgRevoke.SerializeToString,
                response_deserializer=cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgRevokeResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the authz Msg service.
    """

    def Grant(self, request, context):
        """Grant grants the provided authorization to the grantee on the granter's
        account with the provided expiration time. If there is already a grant
        for the given (granter, grantee, Authorization) triple, then the grant
        will be overwritten.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Exec(self, request, context):
        """Exec attempts to execute the provided messages using
        authorizations granted to the grantee. Each message should have only
        one signer corresponding to the granter of the authorization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Revoke(self, request, context):
        """Revoke revokes any authorization corresponding to the provided method name on the
        granter's account that has been granted to the grantee.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Grant': grpc.unary_unary_rpc_method_handler(
                    servicer.Grant,
                    request_deserializer=cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgGrant.FromString,
                    response_serializer=cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgGrantResponse.SerializeToString,
            ),
            'Exec': grpc.unary_unary_rpc_method_handler(
                    servicer.Exec,
                    request_deserializer=cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgExec.FromString,
                    response_serializer=cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgExecResponse.SerializeToString,
            ),
            'Revoke': grpc.unary_unary_rpc_method_handler(
                    servicer.Revoke,
                    request_deserializer=cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgRevoke.FromString,
                    response_serializer=cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgRevokeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.authz.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the authz Msg service.
    """

    @staticmethod
    def Grant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.authz.v1beta1.Msg/Grant',
            cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgGrant.SerializeToString,
            cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgGrantResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Exec(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.authz.v1beta1.Msg/Exec',
            cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgExec.SerializeToString,
            cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgExecResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Revoke(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.authz.v1beta1.Msg/Revoke',
            cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgRevoke.SerializeToString,
            cosmos_dot_authz_dot_v1beta1_dot_tx__pb2.MsgRevokeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/pool.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/peggy/v1/pool.proto',
  package='injective.peggy.v1',
  syntax='proto3',
  serialized_options=b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dinjective/peggy/v1/pool.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\"\x14\n\x05IDSet\x12\x0b\n\x03ids\x18\x01 \x03(\x04\"^\n\tBatchFees\x12\r\n\x05token\x18\x01 \x01(\t\x12\x42\n\ntotal_fees\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x42MZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_IDSET = _descriptor.Descriptor(
  name='IDSet',
  full_name='injective.peggy.v1.IDSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='injective.peggy.v1.IDSet.ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=95,
)


_BATCHFEES = _descriptor.Descriptor(
  name='BatchFees',
  full_name='injective.peggy.v1.BatchFees',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='injective.peggy.v1.BatchFees.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_fees', full_name='injective.peggy.v1.BatchFees.total_fees', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=191,
)

DESCRIPTOR.message_types_by_name['IDSet'] = _IDSET
DESCRIPTOR.message_types_by_name['BatchFees'] = _BATCHFEES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IDSet = _reflection.GeneratedProtocolMessageType('IDSet', (_message.Message,), {
  'DESCRIPTOR' : _IDSET,
  '__module__' : 'injective.peggy.v1.pool_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.IDSet)
  })
_sym_db.RegisterMessage(IDSet)

BatchFees = _reflection.GeneratedProtocolMessageType('BatchFees', (_message.Message,), {
  'DESCRIPTOR' : _BATCHFEES,
  '__module__' : 'injective.peggy.v1.pool_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.BatchFees)
  })
_sym_db.RegisterMessage(BatchFees)


DESCRIPTOR._options = None
_BATCHFEES.fields_by_name['total_fees']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/oracle/v1beta1/tx.proto',
  package='injective.oracle.v1beta1',
  syntax='proto3',
  serialized_options=b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!injective/oracle/v1beta1/tx.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\"\x95\x01\n\x16MsgRelayProviderPrices\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x0f\n\x07symbols\x18\x03 \x03(\t\x12>\n\x06prices\x18\x04 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgRelayProviderPricesResponse\"\x8e\x01\n\x16MsgRelayPriceFeedPrice\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x02 \x03(\t\x12\r\n\x05quote\x18\x03 \x03(\t\x12=\n\x05price\x18\x04 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgRelayPriceFeedPriceResponse\"o\n\x11MsgRelayBandRates\x12\x0f\n\x07relayer\x18\x01 \x01(\t\x12\x0f\n\x07symbols\x18\x02 \x03(\t\x12\r\n\x05rates\x18\x03 \x03(\x04\x12\x15\n\rresolve_times\x18\x04 \x03(\x04\x12\x12\n\nrequestIDs\x18\x05 \x03(\x04\"\x1b\n\x19MsgRelayBandRatesResponse\"Z\n\x18MsgRelayCoinbaseMessages\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08messages\x18\x02 \x03(\x0c\x12\x12\n\nsignatures\x18\x03 \x03(\x0c:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\"\n MsgRelayCoinbaseMessagesResponse\"F\n\x16MsgRequestBandIBCRates\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgRequestBandIBCRatesResponse2\x8f\x05\n\x03Msg\x12\x81\x01\n\x13RelayProviderPrices\x12\x30.injective.oracle.v1beta1.MsgRelayProviderPrices\x1a\x38.injective.oracle.v1beta1.MsgRelayProviderPricesResponse\x12\x81\x01\n\x13RelayPriceFeedPrice\x12\x30.injective.oracle.v1beta1.MsgRelayPriceFeedPrice\x1a\x38.injective.oracle.v1beta1.MsgRelayPriceFeedPriceResponse\x12r\n\x0eRelayBandRates\x12+.injective.oracle.v1beta1.MsgRelayBandRates\x1a\x33.injective.oracle.v1beta1.MsgRelayBandRatesResponse\x12\x81\x01\n\x13RequestBandIBCRates\x12\x30.injective.oracle.v1beta1.MsgRequestBandIBCRates\x1a\x38.injective.oracle.v1beta1.MsgRequestBandIBCRatesResponse\x12\x87\x01\n\x15RelayCoinbaseMessages\x12\x32.injective.oracle.v1beta1.MsgRelayCoinbaseMessages\x1a:.injective.oracle.v1beta1.MsgRelayCoinbaseMessagesResponseBNZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_MSGRELAYPROVIDERPRICES = _descriptor.Descriptor(
  name='MsgRelayProviderPrices',
  full_name='injective.oracle.v1beta1.MsgRelayProviderPrices',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.oracle.v1beta1.MsgRelayProviderPrices.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='injective.oracle.v1beta1.MsgRelayProviderPrices.provider', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbols', full_name='injective.oracle.v1beta1.MsgRelayProviderPrices.symbols', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prices', full_name='injective.oracle.v1beta1.MsgRelayProviderPrices.prices', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=235,
)


_MSGRELAYPROVIDERPRICESRESPONSE = _descriptor.Descriptor(
  name='MsgRelayProviderPricesResponse',
  full_name='injective.oracle.v1beta1.MsgRelayProviderPricesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=269,
)


_MSGRELAYPRICEFEEDPRICE = _descriptor.Descriptor(
  name='MsgRelayPriceFeedPrice',
  full_name='injective.oracle.v1beta1.MsgRelayPriceFeedPrice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.oracle.v1beta1.MsgRelayPriceFeedPrice.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='injective.oracle.v1beta1.MsgRelayPriceFeedPrice.base', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote', full_name='injective.oracle.v1beta1.MsgRelayPriceFeedPrice.quote', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.MsgRelayPriceFeedPrice.price', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=414,
)


_MSGRELAYPRICEFEEDPRICERESPONSE = _descriptor.Descriptor(
  name='MsgRelayPriceFeedPriceResponse',
  full_name='injective.oracle.v1beta1.MsgRelayPriceFeedPriceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=416,
  serialized_end=448,
)


_MSGRELAYBANDRATES = _descriptor.Descriptor(
  name='MsgRelayBandRates',
  full_name='injective.oracle.v1beta1.MsgRelayBandRates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='relayer', full_name='injective.oracle.v1beta1.MsgRelayBandRates.relayer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbols', full_name='injective.oracle.v1beta1.MsgRelayBandRates.symbols', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rates', full_name='injective.oracle.v1beta1.MsgRelayBandRates.rates', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_times', full_name='injective.oracle.v1beta1.MsgRelayBandRates.resolve_times', index=3,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requestIDs', full_name='injective.oracle.v1beta1.MsgRelayBandRates.requestIDs', index=4,
      number=5, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=450,
  serialized_end=561,
)


_MSGRELAYBANDRATESRESPONSE = _descriptor.Descriptor(
  name='MsgRelayBandRatesResponse',
  full_name='injective.oracle.v1beta1.MsgRelayBandRatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=563,
  serialized_end=590,
)


_MSGRELAYCOINBASEMESSAGES = _descriptor.Descriptor(
  name='MsgRelayCoinbaseMessages',
  full_name='injective.oracle.v1beta1.MsgRelayCoinbaseMessages',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.oracle.v1beta1.MsgRelayCoinbaseMessages.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='injective.oracle.v1beta1.MsgRelayCoinbaseMessages.messages', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signatures', full_name='injective.oracle.v1beta1.MsgRelayCoinbaseMessages.signatures', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=682,
)


_MSGRELAYCOINBASEMESSAGESRESPONSE = _descriptor.Descriptor(
  name='MsgRelayCoinbaseMessagesResponse',
  full_name='injective.oracle.v1beta1.MsgRelayCoinbaseMessagesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=684,
  serialized_end=718,
)


_MSGREQUESTBANDIBCRATES = _descriptor.Descriptor(
  name='MsgRequestBandIBCRates',
  full_name='injective.oracle.v1beta1.MsgRequestBandIBCRates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.oracle.v1beta1.MsgRequestBandIBCRates.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='injective.oracle.v1beta1.MsgRequestBandIBCRates.request_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=720,
  serialized_end=790,
)


_MSGREQUESTBANDIBCRATESRESPONSE = _descriptor.Descriptor(
  name='MsgRequestBandIBCRatesResponse',
  full_name='injective.oracle.v1beta1.MsgRequestBandIBCRatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=792,
  serialized_end=824,
)

DESCRIPTOR.message_types_by_name['MsgRelayProviderPrices'] = _MSGRELAYPROVIDERPRICES
DESCRIPTOR.message_types_by_name['MsgRelayProviderPricesResponse'] = _MSGRELAYPROVIDERPRICESRESPONSE
DESCRIPTOR.message_types_by_name['MsgRelayPriceFeedPrice'] = _MSGRELAYPRICEFEEDPRICE
DESCRIPTOR.message_types_by_name['MsgRelayPriceFeedPriceResponse'] = _MSGRELAYPRICEFEEDPRICERESPONSE
DESCRIPTOR.message_types_by_name['MsgRelayBandRates'] = _MSGRELAYBANDRATES
DESCRIPTOR.message_types_by_name['MsgRelayBandRatesResponse'] = _MSGRELAYBANDRATESRESPONSE
DESCRIPTOR.message_types_by_name['MsgRelayCoinbaseMessages'] = _MSGRELAYCOINBASEMESSAGES
DESCRIPTOR.message_types_by_name['MsgRelayCoinbaseMessagesResponse'] = _MSGRELAYCOINBASEMESSAGESRESPONSE
DESCRIPTOR.message_types_by_name['MsgRequestBandIBCRates'] = _MSGREQUESTBANDIBCRATES
DESCRIPTOR.message_types_by_name['MsgRequestBandIBCRatesResponse'] = _MSGREQUESTBANDIBCRATESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgRelayProviderPrices = _reflection.GeneratedProtocolMessageType('MsgRelayProviderPrices', (_message.Message,), {
  'DESCRIPTOR' : _MSGRELAYPROVIDERPRICES,
  '__module__' : 'injective.oracle.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.MsgRelayProviderPrices)
  })
_sym_db.RegisterMessage(MsgRelayProviderPrices)

MsgRelayProviderPricesResponse = _reflection.GeneratedProtocolMessageType('MsgRelayProviderPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGRELAYPROVIDERPRICESRESPONSE,
  '__module__' : 'injective.oracle.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.MsgRelayProviderPricesResponse)
  })
_sym_db.RegisterMessage(MsgRelayProviderPricesResponse)

MsgRelayPriceFeedPrice = _reflection.GeneratedProtocolMessageType('MsgRelayPriceFeedPrice', (_message.Message,), {
  'DESCRIPTOR' : _MSGRELAYPRICEFEEDPRICE,
  '__module__' : 'injective.oracle.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.MsgRelayPriceFeedPrice)
  })
_sym_db.RegisterMessage(MsgRelayPriceFeedPrice)

MsgRelayPriceFeedPriceResponse = _reflection.GeneratedProtocolMessageType('MsgRelayPriceFeedPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGRELAYPRICEFEEDPRICERESPONSE,
  '__module__' : 'injective.oracle.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.MsgRelayPriceFeedPriceResponse)
  })
_sym_db.RegisterMessage(MsgRelayPriceFeedPriceResponse)

MsgRelayBandRates = _reflection.GeneratedProtocolMessageType('MsgRelayBandRates', (_message.Message,), {
  'DESCRIPTOR' : _MSGRELAYBANDRATES,
  '__module__' : 'injective.oracle.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.MsgRelayBandRates)
  })
_sym_db.RegisterMessage(MsgRelayBandRates)

MsgRelayBandRatesResponse = _reflection.GeneratedProtocolMessageType('MsgRelayBandRatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGRELAYBANDRATESRESPONSE,
  '__module__' : 'injective.oracle.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.MsgRelayBandRatesResponse)
  })
_sym_db.RegisterMessage(MsgRelayBandRatesResponse)

MsgRelayCoinbaseMessages = _reflection.GeneratedProtocolMessageType('MsgRelayCoinbaseMessages', (_message.Message,), {
  'DESCRIPTOR' : _MSGRELAYCOINBASEMESSAGES,
  '__module__' : 'injective.oracle.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.MsgRelayCoinbaseMessages)
  })
_sym_db.RegisterMessage(MsgRelayCoinbaseMessages)

MsgRelayCoinbaseMessagesResponse = _reflection.GeneratedProtocolMessageType('MsgRelayCoinbaseMessagesResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGRELAYCOINBASEMESSAGESRESPONSE,
  '__module__' : 'injective.oracle.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.MsgRelayCoinbaseMessagesResponse)
  })
_sym_db.RegisterMessage(MsgRelayCoinbaseMessagesResponse)

MsgRequestBandIBCRates = _reflection.GeneratedProtocolMessageType('MsgRequestBandIBCRates', (_message.Message,), {
  'DESCRIPTOR' : _MSGREQUESTBANDIBCRATES,
  '__module__' : 'injective.oracle.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.MsgRequestBandIBCRates)
  })
_sym_db.RegisterMessage(MsgRequestBandIBCRates)

MsgRequestBandIBCRatesResponse = _reflection.GeneratedProtocolMessageType('MsgRequestBandIBCRatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREQUESTBANDIBCRATESRESPONSE,
  '__module__' : 'injective.oracle.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.MsgRequestBandIBCRatesResponse)
  })
_sym_db.RegisterMessage(MsgRequestBandIBCRatesResponse)


DESCRIPTOR._options = None
_MSGRELAYPROVIDERPRICES.fields_by_name['prices']._options = None
_MSGRELAYPROVIDERPRICES._options = None
_MSGRELAYPRICEFEEDPRICE.fields_by_name['price']._options = None
_MSGRELAYPRICEFEEDPRICE._options = None
_MSGRELAYCOINBASEMESSAGES._options = None
_MSGREQUESTBANDIBCRATES._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='injective.oracle.v1beta1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=827,
  serialized_end=1482,
  methods=[
  _descriptor.MethodDescriptor(
    name='RelayProviderPrices',
    full_name='injective.oracle.v1beta1.Msg.RelayProviderPrices',
    index=0,
    containing_service=None,
    input_type=_MSGRELAYPROVIDERPRICES,
    output_type=_MSGRELAYPROVIDERPRICESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RelayPriceFeedPrice',
    full_name='injective.oracle.v1beta1.Msg.RelayPriceFeedPrice',
    index=1,
    containing_service=None,
    input_type=_MSGRELAYPRICEFEEDPRICE,
    output_type=_MSGRELAYPRICEFEEDPRICERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RelayBandRates',
    full_name='injective.oracle.v1beta1.Msg.RelayBandRates',
    index=2,
    containing_service=None,
    input_type=_MSGRELAYBANDRATES,
    output_type=_MSGRELAYBANDRATESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestBandIBCRates',
    full_name='injective.oracle.v1beta1.Msg.RequestBandIBCRates',
    index=3,
    containing_service=None,
    input_type=_MSGREQUESTBANDIBCRATES,
    output_type=_MSGREQUESTBANDIBCRATESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RelayCoinbaseMessages',
    full_name='injective.oracle.v1beta1.Msg.RelayCoinbaseMessages',
    index=4,
    containing_service=None,
    input_type=_MSGRELAYCOINBASEMESSAGES,
    output_type=_MSGRELAYCOINBASEMESSAGESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/staking/v1beta1/authz.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/staking/v1beta1/authz.proto',
  package='cosmos.staking.v1beta1',
  syntax='proto3',
  serialized_options=b'Z,github.com/cosmos/cosmos-sdk/x/staking/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"cosmos/staking/v1beta1/authz.proto\x12\x16\x63osmos.staking.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x90\x03\n\x12StakeAuthorization\x12Z\n\nmax_tokens\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB+\xaa\xdf\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\x12K\n\nallow_list\x18\x02 \x01(\x0b\x32\x35.cosmos.staking.v1beta1.StakeAuthorization.ValidatorsH\x00\x12J\n\tdeny_list\x18\x03 \x01(\x0b\x32\x35.cosmos.staking.v1beta1.StakeAuthorization.ValidatorsH\x00\x12\x45\n\x12\x61uthorization_type\x18\x04 \x01(\x0e\x32).cosmos.staking.v1beta1.AuthorizationType\x1a\x1d\n\nValidators\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x03(\t:\x11\xd2\xb4-\rAuthorizationB\x0c\n\nvalidators*\x9e\x01\n\x11\x41uthorizationType\x12\"\n\x1e\x41UTHORIZATION_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x41UTHORIZATION_TYPE_DELEGATE\x10\x01\x12!\n\x1d\x41UTHORIZATION_TYPE_UNDELEGATE\x10\x02\x12!\n\x1d\x41UTHORIZATION_TYPE_REDELEGATE\x10\x03\x42.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos__proto_dot_cosmos__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])

_AUTHORIZATIONTYPE = _descriptor.EnumDescriptor(
  name='AuthorizationType',
  full_name='cosmos.staking.v1beta1.AuthorizationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_TYPE_DELEGATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_TYPE_UNDELEGATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_TYPE_REDELEGATE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=547,
  serialized_end=705,
)
_sym_db.RegisterEnumDescriptor(_AUTHORIZATIONTYPE)

AuthorizationType = enum_type_wrapper.EnumTypeWrapper(_AUTHORIZATIONTYPE)
AUTHORIZATION_TYPE_UNSPECIFIED = 0
AUTHORIZATION_TYPE_DELEGATE = 1
AUTHORIZATION_TYPE_UNDELEGATE = 2
AUTHORIZATION_TYPE_REDELEGATE = 3



_STAKEAUTHORIZATION_VALIDATORS = _descriptor.Descriptor(
  name='Validators',
  full_name='cosmos.staking.v1beta1.StakeAuthorization.Validators',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmos.staking.v1beta1.StakeAuthorization.Validators.address', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=482,
  serialized_end=511,
)

_STAKEAUTHORIZATION = _descriptor.Descriptor(
  name='StakeAuthorization',
  full_name='cosmos.staking.v1beta1.StakeAuthorization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_tokens', full_name='cosmos.staking.v1beta1.StakeAuthorization.max_tokens', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\252\337\037\'github.com/cosmos/cosmos-sdk/types.Coin', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_list', full_name='cosmos.staking.v1beta1.StakeAuthorization.allow_list', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deny_list', full_name='cosmos.staking.v1beta1.StakeAuthorization.deny_list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorization_type', full_name='cosmos.staking.v1beta1.StakeAuthorization.authorization_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STAKEAUTHORIZATION_VALIDATORS, ],
  enum_types=[
  ],
  serialized_options=b'\322\264-\rAuthorization',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='validators', full_name='cosmos.staking.v1beta1.StakeAuthorization.validators',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=144,
  serialized_end=544,
)

_STAKEAUTHORIZATION_VALIDATORS.containing_type = _STAKEAUTHORIZATION
_STAKEAUTHORIZATION.fields_by_name['max_tokens'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_STAKEAUTHORIZATION.fields_by_name['allow_list'].message_type = _STAKEAUTHORIZATION_VALIDATORS
_STAKEAUTHORIZATION.fields_by_name['deny_list'].message_type = _STAKEAUTHORIZATION_VALIDATORS
_STAKEAUTHORIZATION.fields_by_name['authorization_type'].enum_type = _AUTHORIZATIONTYPE
_STAKEAUTHORIZATION.oneofs_by_name['validators'].fields.append(
  _STAKEAUTHORIZATION.fields_by_name['allow_list'])
_STAKEAUTHORIZATION.fields_by_name['allow_list'].containing_oneof = _STAKEAUTHORIZATION.oneofs_by_name['validators']
_STAKEAUTHORIZATION.oneofs_by_name['validators'].fields.append(
  _STAKEAUTHORIZATION.fields_by_name['deny_list'])
_STAKEAUTHORIZATION.fields_by_name['deny_list'].containing_oneof = _STAKEAUTHORIZATION.oneofs_by_name['validators']
DESCRIPTOR.message_types_by_name['StakeAuthorization'] = _STAKEAUTHORIZATION
DESCRIPTOR.enum_types_by_name['AuthorizationType'] = _AUTHORIZATIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StakeAuthorization = _reflection.GeneratedProtocolMessageType('StakeAuthorization', (_message.Message,), {

  'Validators' : _reflection.GeneratedProtocolMessageType('Validators', (_message.Message,), {
    'DESCRIPTOR' : _STAKEAUTHORIZATION_VALIDATORS,
    '__module__' : 'cosmos.staking.v1beta1.authz_pb2'
    # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.StakeAuthorization.Validators)
    })
  ,
  'DESCRIPTOR' : _STAKEAUTHORIZATION,
  '__module__' : 'cosmos.staking.v1beta1.authz_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.StakeAuthorization)
  })
_sym_db.RegisterMessage(StakeAuthorization)
_sym_db.RegisterMessage(StakeAuthorization.Validators)


DESCRIPTOR._options = None
_STAKEAUTHORIZATION.fields_by_name['max_tokens']._options = None
_STAKEAUTHORIZATION._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/params/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.params.v1beta1 import params_pb2 as cosmos_dot_params_dot_v1beta1_dot_params__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/params/v1beta1/query.proto',
  package='cosmos.params.v1beta1',
  syntax='proto3',
  serialized_options=b'Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!cosmos/params/v1beta1/query.proto\x12\x15\x63osmos.params.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\"cosmos/params/v1beta1/params.proto\"3\n\x12QueryParamsRequest\x12\x10\n\x08subspace\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"N\n\x13QueryParamsResponse\x12\x37\n\x05param\x18\x01 \x01(\x0b\x32\".cosmos.params.v1beta1.ParamChangeB\x04\xc8\xde\x1f\x00\x32\x90\x01\n\x05Query\x12\x86\x01\n\x06Params\x12).cosmos.params.v1beta1.QueryParamsRequest\x1a*.cosmos.params.v1beta1.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/params/v1beta1/paramsB6Z4github.com/cosmos/cosmos-sdk/x/params/types/proposalb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,cosmos_dot_params_dot_v1beta1_dot_params__pb2.DESCRIPTOR,])




_QUERYPARAMSREQUEST = _descriptor.Descriptor(
  name='QueryParamsRequest',
  full_name='cosmos.params.v1beta1.QueryParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subspace', full_name='cosmos.params.v1beta1.QueryParamsRequest.subspace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='cosmos.params.v1beta1.QueryParamsRequest.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=199,
)


_QUERYPARAMSRESPONSE = _descriptor.Descriptor(
  name='QueryParamsResponse',
  full_name='cosmos.params.v1beta1.QueryParamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='param', full_name='cosmos.params.v1beta1.QueryParamsResponse.param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=279,
)

_QUERYPARAMSRESPONSE.fields_by_name['param'].message_type = cosmos_dot_params_dot_v1beta1_dot_params__pb2._PARAMCHANGE
DESCRIPTOR.message_types_by_name['QueryParamsRequest'] = _QUERYPARAMSREQUEST
DESCRIPTOR.message_types_by_name['QueryParamsResponse'] = _QUERYPARAMSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'cosmos.params.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.params.v1beta1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'cosmos.params.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.params.v1beta1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)


DESCRIPTOR._options = None
_QUERYPARAMSRESPONSE.fields_by_name['param']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='cosmos.params.v1beta1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=282,
  serialized_end=426,
  methods=[
  _descriptor.MethodDescriptor(
    name='Params',
    full_name='cosmos.params.v1beta1.Query.Params',
    index=0,
    containing_service=None,
    input_type=_QUERYPARAMSREQUEST,
    output_type=_QUERYPARAMSRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\022\035/cosmos/params/v1beta1/params',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)



from decimal import Decimal
from math import floor

"""
One thing you may need to pay more attention to is how to deal with decimals on the Injective Exchange.
Different cryptocurrencies may require different decimal precisions. More specifically, ERC-20 tokens(e.g. INJ) have 18 decimals whereas USDT/USC have 6 decimals.
So in our system that means ** having 1 INJ is 1e18 inj ** and that ** 1 USDT is actually 100000 peggy0xdac17f958d2ee523a2206206994597c13d831ec7**.

For spot markets, a price reflects the ** relative exchange rate ** between two tokens.
If the tokens have the same decimal scale, that's great since the prices become interpretable e.g. USDT/USDC (both have 6 decimals e.g. for USDT https://etherscan.io/address/0xdac17f958d2ee523a2206206994597c13d831ec7#readContract)
or MATIC/INJ (both have 18 decimals) since the decimals cancel out.
Prices however start to look wonky once you have exchanges between two tokens of different decimals, which unfortunately is most pairs with USDT or USDC denominations e.g. INJ/USDT.
As such, I've created some simple utility functions by keeping a hardcoded dictionary in injective-py and you can also achieve such utilities by yourself
(e.g. you can use external API like Alchemy's getTokenMetadata to fetch decimal of base and quote asset).

So for INJ/USDT of 6.9, the price you end up getting is 6.9*10 ^ (6 - 18) = 6.9e-12. Note that this market also happens to have a MinPriceTickSize of 1e-15.
This makes sense since since it's defining th3e minimum price increment of the relative exchange of INJ to USDT.

Note that this market also happens to have a MinQuantityTickSize of 1e15.
This also makes sense since it refers to the minimum INJ quantity tick size each order must have, which is 1e15/1e18 = 0.001 INJ.

"""

def spot_price_to_backend(price, denom) -> int:
    price_tick_size = denom.min_price_tick_size
    scale_price = Decimal(18 + denom.quote - denom.base)
    exchange_price = floor_to(price, price_tick_size) * pow(Decimal(10), scale_price)
    return int(exchange_price)

def spot_quantity_to_backend(quantity, denom) -> int:
    quantity_tick_size = float(denom.min_quantity_tick_size) / pow(10, denom.base)
    scale_quantity = Decimal(18 + denom.base)
    exchange_quantity = floor_to(quantity, quantity_tick_size) * pow(Decimal(10), scale_quantity)
    return int(exchange_quantity)

def derivative_price_to_backend(price, denom) -> int:
    price_tick_size = Decimal(denom.min_price_tick_size) / pow(10, denom.quote)
    exchange_price = floor_to(price, float(price_tick_size)) * pow(10, 18 + denom.quote)
    return int(exchange_price)

def binary_options_price_to_backend(price, denom) -> int:
    price_tick_size = Decimal(denom.min_price_tick_size) / pow(10, denom.quote)
    exchange_price = floor_to(price, float(price_tick_size)) * pow(10, 18 + denom.quote)
    return int(exchange_price)

def derivative_quantity_to_backend(quantity, denom) -> int:
    quantity_tick_size = float(denom.min_quantity_tick_size) / pow(10, denom.base)
    scale_quantity = Decimal(18 + denom.base)
    exchange_quantity = floor_to(quantity, quantity_tick_size) * pow(Decimal(10), scale_quantity)
    return int(exchange_quantity)

def binary_options_quantity_to_backend(quantity, denom) -> int:
    quantity_tick_size = float(denom.min_quantity_tick_size) / pow(10, denom.base)
    scale_quantity = Decimal(18 + denom.base)
    exchange_quantity = floor_to(quantity, quantity_tick_size) * pow(Decimal(10), scale_quantity)
    return int(exchange_quantity)

def derivative_margin_to_backend(price, quantity, leverage, denom) -> int:
    price_tick_size = Decimal(denom.min_price_tick_size) / pow(10, denom.quote)
    margin = (price * quantity) / leverage
    exchange_margin = floor_to(margin, float(price_tick_size)) * pow(10, 18 + denom.quote)
    return int(exchange_margin)

def binary_options_buy_margin_to_backend(price, quantity, denom) -> int:
    price_tick_size = Decimal(denom.min_price_tick_size) / pow(10, denom.quote)
    margin = Decimal(str(price)) * Decimal(str(quantity))
    exchange_margin = floor_to(margin, float(price_tick_size)) * pow(10, 18 + denom.quote)
    return int(exchange_margin)

def binary_options_sell_margin_to_backend(price, quantity, denom) -> int:
    price_tick_size = Decimal(denom.min_price_tick_size) / pow(10, denom.quote)
    margin = (1 - (Decimal(str(price)) / pow (10, denom.quote))) * Decimal(str(quantity))
    exchange_margin = floor_to(margin, float(price_tick_size)) * pow(10, 18 + denom.quote)
    return int(exchange_margin)

def derivative_additional_margin_to_backend(amount, denom) -> int:
    price_tick_size = float(denom.min_price_tick_size) / pow(10, denom.quote)
    additional_margin = floor_to(amount, price_tick_size) * pow(10, 18 + denom.quote)
    return int(additional_margin)

def amount_to_backend(amount, decimals) -> int:
    be_amount = amount * pow(10, decimals)
    return int(be_amount)

def floor_to(value: float, target: float) -> Decimal:
    value_tmp = Decimal(str(value))
    target_tmp = Decimal(str(target))
    result = int(floor(value_tmp / target_tmp)) * target_tmp
    return result

def spot_price_from_backend(price, denom) -> float:
    scale = float(denom.quote - denom.base)
    return float(price) / pow(10, scale)

def spot_quantity_from_backend(quantity, denom) -> Decimal:
    scale = float(denom.base)
    quantity_tick_size = float(denom.min_quantity_tick_size) / pow(10, scale)
    quantity = float(quantity) / pow(10, scale)
    return floor_to(quantity, quantity_tick_size)

def derivative_price_from_backend(price, denom) -> float:
    scale = float(denom.quote)
    return float(price) / pow(10, scale)
